==> luckperms-api-4.2-sources.jar: me/lucko/luckperms/api/event/track/mutate/TrackMutateEvent.java <==
/*
 * This file is part of LuckPerms, licensed under the MIT License.
 *
 *  Copyright (c) lucko (Luck) <luck@lucko.me>
 *  Copyright (c) contributors
 *
 *  Permission is hereby granted, free of charge, to any person obtaining a copy
 *  of this software and associated documentation files (the "Software"), to deal
 *  in the Software without restriction, including without limitation the rights
 *  to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 *  copies of the Software, and to permit persons to whom the Software is
 *  furnished to do so, subject to the following conditions:
 *
 *  The above copyright notice and this permission notice shall be included in all
 *  copies or substantial portions of the Software.
 *
 *  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 *  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 *  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 *  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 *  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 *  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 *  SOFTWARE.
 */

package me.lucko.luckperms.api.event.track.mutate;

import me.lucko.luckperms.api.Track;
import me.lucko.luckperms.api.event.LuckPermsEvent;

import java.util.List;

import javax.annotation.Nonnull;

/**
 * Called when a track is changed
 */
public interface TrackMutateEvent extends LuckPermsEvent {

    /**
     * Gets the track that was mutated
     *
     * @return the track that was mutated
     */
    @Nonnull
    Track getTrack();

    /**
     * Gets an immutable copy of the tracks data before the change
     *
     * @return the data before the change
     */
    @Nonnull
    List<String> getDataBefore();

    /**
     * Gets an immutable copy of the tracks data after the change
     *
     * @return the data after the change
     */
    @Nonnull
    List<String> getDataAfter();

}

==> luckperms-api-4.4-sources.jar: me/lucko/luckperms/api/event/track/mutate/TrackMutateEvent.java <==
/*
 * This file is part of LuckPerms, licensed under the MIT License.
 *
 *  Copyright (c) lucko (Luck) <luck@lucko.me>
 *  Copyright (c) contributors
 *
 *  Permission is hereby granted, free of charge, to any person obtaining a copy
 *  of this software and associated documentation files (the "Software"), to deal
 *  in the Software without restriction, including without limitation the rights
 *  to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 *  copies of the Software, and to permit persons to whom the Software is
 *  furnished to do so, subject to the following conditions:
 *
 *  The above copyright notice and this permission notice shall be included in all
 *  copies or substantial portions of the Software.
 *
 *  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 *  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 *  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 *  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 *  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 *  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 *  SOFTWARE.
 */

package me.lucko.luckperms.api.event.track.mutate;

import me.lucko.luckperms.api.Track;
import me.lucko.luckperms.api.event.LuckPermsEvent;
import me.lucko.luckperms.api.event.Param;

import org.checkerframework.checker.nullness.qual.NonNull;

import java.util.List;

/**
 * Called when a track is changed
 */
public interface TrackMutateEvent extends LuckPermsEvent {

    /**
     * Gets the track that was mutated
     *
     * @return the track that was mutated
     */
    @NonNull @Param(0) Track getTrack();

    /**
     * Gets an immutable copy of the tracks data before the change
     *
     * @return the data before the change
     */
    @NonNull @Param(1) List<String> getDataBefore();

    /**
     * Gets an immutable copy of the tracks data after the change
     *
     * @return the data after the change
     */
    @NonNull @Param(2) List<String> getDataAfter();

}
